@@ -24,6 +24,11 @@
 
 #include <couchdb-glib.h>
 
+#define COUCHDB_RECORD_TYPE_CONTACT "http://www.freedesktop.org/wiki/Specifications/desktopcouch/contact"
+
+CouchDBDocument *couchdb_document_contact_new (CouchDB *couchdb);
+gboolean         couchdb_document_is_contact (CouchDBDocument *document);
+
 /*
  * Top level functions to manipulate documents representing a contact
  */
