@@ -22,8 +22,7 @@
 #include <libsoup/soup-logger.h>
 #include <libsoup/soup-session-async.h>
 #include <libsoup/soup-gnome.h>
-#include <json-glib/json-parser.h>
-#include <json-glib/json-generator.h>
+#include <json-glib/json-glib.h>
 #include "couchdb-glib.h"
 #include "utils.h"
 
@@ -228,14 +227,30 @@ couchdb_document_set_revision (CouchDBDocument *document, const char *revision)
 				       revision);
 }
 
-gboolean
-couchdb_document_is_contact (CouchDBDocument *document)
+const char *
+couchdb_document_get_record_type (CouchDBDocument *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 
-	return !g_ascii_strcasecmp (json_object_get_string_member (json_node_get_object (document->root_node),
-								   "record_type"),
-				    "http://www.freedesktop.org/wiki/Specifications/desktopcouch/contact");
+	if (document->root_node &&
+	    json_node_get_node_type (document->root_node) == JSON_NODE_OBJECT) {
+		return json_object_get_string_member (
+			json_node_get_object (document->root_node),
+			"record_type");
+	}
+
+	return NULL;
+}
+
+void
+couchdb_document_set_record_type (CouchDBDocument *document, const char *record_type)
+{
+	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (record_type != NULL);
+
+	json_object_set_string_member (json_node_get_object (document->root_node),
+				       "record_type",
+				       record_type);
 }
 
 gboolean
@@ -370,6 +385,22 @@ couchdb_document_set_struct_field (CouchDBDocument *document, const char *field,
 				       json_object_ref (value->json_object));
 }
 
+CouchDBStructField *
+couchdb_document_get_application_annotations (CouchDBDocument *document)
+{
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
+
+	return couchdb_document_get_struct_field (document, "application_annotations");
+}
+
+void
+couchdb_document_set_application_annotations (CouchDBDocument *document, CouchDBStructField *annotations)
+{
+	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+
+	couchdb_document_set_struct_field (document, "application_annotations", annotations);
+}
+
 char *
 couchdb_document_to_string (CouchDBDocument *document)
 {
